@@ -148,7 +148,6 @@ class Workbook(object):
 
         # Load the shared strings and populate the string table
         self.load_XML('xl/sharedStrings.xml')
-        self.load_XML('xl/calcChain.xml')
         xml = self.xmls.get('xl/sharedStrings.xml', None)
         self.string_table = []
         if xml:
@@ -212,7 +211,9 @@ class Workbook(object):
             # Write the zip file
             zipFilename = self.zip.filename
             self.zip.close()
-            self.remove_from_zip(zipFilename, self.xmls.keys())
+            remove_list = self.xmls.keys()
+            remove_list.append('xl/calcChain.xml')  # Force excel to recreate to avoid errors.
+            self.remove_from_zip(zipFilename, remove_list)
             updateZip = ZipFile(zipFilename, 'a')
             for filename in self.xmls.keys():
                 updateZip.write(join(self.path, filename), filename)
